<template>
  <div>
    <li>
      <a
        class="kioskbutton"
        data-control="PopupTrigger"
        @click.prevent="$refs.shoppingModal.Open()"><img src="/images/kiosk-button4-shop.png"></a>
    </li>
    <shopping-modal ref="shoppingModal">
      <div
        id="overlay"
        slot="shopping">
        <section
          id="shopwindow"
          data-control="Popup"
          class="modalwindow">
          <div class="windowcontent">
            <p>Shop</p>
            <div class="productcontainer">
              <div v-if="products.dogtag.id != 0 && choosePurchase.type !== 'briefcase'">
                <div
                  v-if="products.dogtag.isSoldOut === true"
                  class="dogtags dogtagbuy unavailable">
                  <div class="notavailable">Dog Tag<br>sold out
                  </div>
                </div>
                <div
                  v-else
                  class="dogtags dogtagbuy"
                  @click="choosePurchase = products.dogtag">
                  <div class="productlabel">Dog Tag</div>
                </div>
                <form
                  v-if="choosePurchase.id"
                  id="shopformDogTag">
                  <label
                    style="margin-bottom: 2rem;"
                    for="delivery">Where are you working today?</label>
                  <select v-model="employedAt">
                    <option
                      value="Please Select A Shop...">Please Select A Shop...
                    </option>
                    <option
                      v-for="(shop, index) in shops"
                      :key="index"
                      :value="shop.account">{{ shop.name }}
                    </option>
                  </select>
                  <label
                    for="engrave"
                    class="dstuff">What 3 letters would you like engraved on your dog tag?</label>
                  <input
                    id="engrave"
                    v-model="personalization"
                    type="text"
                    name="engrave"
                    maxlength="3"
                    class="dstuff">
                </form>
              </div>
              <div v-if="products.briefcase.id != 0 && choosePurchase.type !== 'dogtag'">
                <div
                  v-if="products.briefcase.isSoldOut === true"
                  class="briefcase briefcasebuy unavailable">
                  <div class="notavailable">Briefcase<br>sold out</div>
                </div>
                <div
                  v-else
                  class="briefcase briefcasebuy"
                  @click="choosePurchase = products.briefcase">
                  <div class="productlabel">Briefcase</div>
                </div>
                <form
                  v-if="choosePurchase.id"
                  id="shopform">
                  <label
                    style="margin-bottom: 2rem;"
                    for="delivery">Where are you working today?</label>
                  <select v-model="employedAt">
                    <option
                      value="Please Select A Shop...">Please Select A Shop...
                    </option>
                    <option
                      v-for="(shop, index) in shops"
                      :key="index"
                      :value="shop.account">{{ shop.name }}
                    </option>
                  </select>
                </form>
              </div>
            </div>
            <div
              v-if="choosePurchase.id"
              id="ordertotal"
              class="shopconfirm"
              style="display: block;">
              Total: $<span class="orderTotal">{{ choosePurchase.price }}</span>
            </div>
            <div
              v-if="choosePurchase.id && !orderComplete"
              class="popupbuttoncontainer orderbutton shopconfirm"
              style="display: block;"
              @click="checkOverdraftStatus()">
              <div class="popupbtn buttonleft"/>
              <div class="popupbtn buttonmiddle">{{ orderStep }}
              </div>
              <div class="popupbtn buttonright"/>
              <div class="clear"/>
            </div>
            <div
              v-if="orderComplete"
              class="popupbuttoncontainer orderbutton shopconfirm"
              style="display: block;"
              @click="$refs.shoppingModal.Close(); resetShoppingModal()">
              <div class="popupbtn buttonleft"/>
              <div class="popupbtn buttonmiddle">Done!
              </div>
              <div class="popupbtn buttonright"/>
              <div class="clear"/>
            </div>
            <div
              v-if="!choosePurchase.id && products.dogtag.isSoldOut === false && products.dogtag.id !== 0"
              id="dogtagbuybutton"
              class="buybuttons">
              <div
                id="dogtagbuy"
                class="shopbutton dogtagbuy"
                @click="choosePurchase = products.dogtag">
                <div class="price">${{ products.dogtag.price }}</div>
                <div class="buy">Buy!</div>
              </div>
            </div>
            <div
              v-if="!choosePurchase.id && products.briefcase.isSoldOut === false"
              id="briefcasebuybutton"
              class="buybuttons">
              <div
                id="briefcasebuy"
                class="shopbutton briefcasebuy"
                @click="choosePurchase = products.briefcase">
                <div class="price">${{ products.briefcase.price }}</div>
                <div class="buy">Buy!</div>
              </div>
            </div>
          </div>
          <a
            class="close closebutton maskfadeout"
            data-dismiss="modal"
            @click="$refs.shoppingModal.Close(); resetShoppingModal()"><img src="/images/closebutton.png"></a>
        </section>
      </div>
    </shopping-modal>
  </div>
</template>

<script>
import ShoppingModal from "../../../shared/views/ShopModal.vue";
export default {
  components: {
    ShoppingModal
  },
  props:{
    account: {
      type: Object,
      default() {
        return {};
      }
    }
  },
  data() {
    return {
      shops: [],
      employedAt: "Please Select A Shop...",
      personalization:"",
      choosePurchase:{},
      products:{
        "briefcase":{
          "type":"briefcase",
          "price":0,
          "isSoldOut":false,
          "id":0,
          "name":"Briefcase"
        },
        "dogtag":{
          "type":"dogtag",
          "price":0,
          "isSoldOut":false,
          "id":0,
          "name":"Dog Tag"
        }
      },
      processingOrder: false,
      orderComplete: false
    };
  },
  computed: {
    orderStep: function () {
      if (this.processingOrder) {
        return "PROCESSING...";
      } else {
        return "PLACE ORDER";
      }
    }
  },
  watch: {
    account: function() {
      if(this.account.products){
        this.formatProducts();
      }
    }
  },
  beforeMount: function () {
    this.getShops();
  },
  methods: {
    getShops() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/economies/getAllWithAccountIds/" + app.session.data.id)
          .then( Response => {
            Response.forEach(shop => {
              this.shops.push({name: shop.pretty_name, account: shop.accountId});
            });
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    checkOverdraftStatus() {
      this.processingOrder = true;
      app.api.Get(`accounts/checkoverdraftstatus/${this.account.accountId}`)
        .then( response => {
          if(response !== "okay") {
            app.Message("We're sorry, your card has been declined. Please see a staff person for help.", "warn");
            this.processingOrder = false;
          } else {
            this.purchase();
          }
        });
    },
    purchase(){
      if(this.employedAt === "Please Select A Shop..."){
        app.Message( "Please make a selection", "error" );
      }
      else{
        let payload = {
          "product":this.choosePurchase.id,
          "onlinePurchase": {
            "to": "",
            "from":this.account.accountId,
            "session":app.session.data.id,
            "name":"Kiosk order " + this.choosePurchase.name,
            "type":"debitKiosk",
            "amount":this.choosePurchase.price
          },
          "accountId":this.account.accountId,
          "order" : {
            "destination":this.employedAt,
            "personalization":this.personalization
          }
        };
        if (payload.product === this.products.dogtag.id) {
          payload.onlinePurchase.to = 311;
        } else {
          if (app.network.data.name !== "YAT 10") {
            payload.onlinePurchase.to = 309;
          } else {
            payload.onlinePurchase.to = 311;
          }
        }
        app.api.Post( "/kiosk/onlineorder/", payload)
          .then( Response => {
            let self = this;
            self.orderComplete = true;
            app.Message( "Thank you! Your order has been placed", "success");
            setTimeout( function(){
              self.$refs.shoppingModal.Close();
              self.resetShoppingModal();
            }, 2000);
            // emit account fetch
              this.$emit("refresh-account");
          })
          .catch( x => app.Message( x.error, "error" ) );
      }
    },
    formatProducts(){
        this.account.products.forEach(product => {
          if(product.type === "briefcase"){
            this.products.briefcase.id = product.id;
            this.products.briefcase.price = product.price;
            if(product.stock <= 0){
              this.products.briefcase.isSoldOut = true;
            }
          }
          if(product.type === "dogtag"){
            this.products.dogtag.id = product.id;
            this.products.dogtag.price = product.price;
            if(product.stock <= 0){
              this.products.dogtag.isSoldOut = true;
            }
          }
      });
    },
    resetShoppingModal() {
      this.employedAt = "Please Select A Shop...";
      this.personalization = "";
      this.choosePurchase = {};
      this.processingOrder = false;
      this.orderComplete = false;
    },
  }
};
</script>

<style>

</style>
